////////////////////////////////////////////////
// @运行时
////////////////////////////////////////////////

if (typeof (GSApp.API) == "undefined")
{
    GSApp.API = function () { };
}

////////////////////////////////////////////////
// @相关内容API
////////////////////////////////////////////////

GSApp.API.RelatedContent = function () { };

/**
 * 使用指定参数获取相关内容信息。
 *
 * @param {int} contentId, 原文内容Id。
 * @param {string} contentType, 原文内容Id。
 * @param {int} gameId, 相关游戏Id。
 * @param {string} type, 内容类型，可选值有：xinWen，获取相关新闻内容，gongLue，获取相关攻略内容，tuiJianGongLue，获取推荐相关攻略内容，shiPin，获取相关视频内容。
 * @param {string} order, 排序方式，可选值有：pvDESC，按总PV降序排序，timeDESC，按发布时间降序排序。
 * @param {int} pageIndex, 分页索引值。
 * @param {int} pageSize, 分页元素数。
 * @param {function} didReceiveRelatedContentInfes, 用于接收相关内容信息的回调函数，拥有唯一参数：GSApp.Modules.ListElement[]，相关内容信息数组。
 * @returns 没有返回值。
 */
GSApp.API.RelatedContent.getWithContentId = function (
    contentId,
    contentType,
    gameId,
    type,
    order,
    pageIndex,
    pageSize,
    didReceiveRelatedContentInfes)
{
    if (typeof (didReceiveRelatedContentInfes) == "undefined"
        || didReceiveRelatedContentInfes == null)
    {
        return;
    }

    if (contentId < 1)
    {
        didReceiveRelatedContentInfes(new Array());
        return;
    }

    if (pageIndex < 0)
    {
        didReceiveRelatedContentInfes(new Array());
        return;
    }

    switch (type)
    {
        case "xinWen":
            {
                type = "news";
            } break;
        case "gongLue":
            {
                type = "strategy";
            } break;
        case "tuiJianGongLue":
            {
                type = "recommendedStrategy";
            } break;
        case "shiPin":
            {
                type = "video";
            } break;
    }

    switch (order)
    {
        case "pvDESC":
            {
                order = "view";
            } break;
        case "timeDESC":
            {
                order = "date";
            } break;
    }

    // contentId,
    //     contentType,
    //     gameId,
    //     type,
    //     order,
    //     pageIndex,
    //     pageSize,
    //     didReceiveRelatedContentInfes

    var requestParams =
    {
        "contentId": contentId,
        "contentType": contentType,
        "gameId": gameId.toString(),

        "correlationFilter": type,
        "order": order,

        "pageIndex": pageIndex,
        "elementsCountPerPage": pageSize
    };

    var appCallback = new GSApp.API.AppCallback(function (response)
    {
        try
        {
            if (response.result != null &&
                response.result != undefined)
            {
                response = response.result;
            }
            else
            {
                response = response;
            }

            var relatedContentInfes = new Array();
            if (response != null &&
                response instanceof Array)
            {
                for (var i = 0; i < response.length; i++)
                {
                    // {
                    //     "contentId": "196691",
                    //     "type": "xinwen",
                    //     "contentType": "news",
                    //     "title": "让你瞬间想歪 海量爆笑趣味图欣赏",
                    //     "description": null,
                    //     "thumbnailUrl": "https://imgs.gamersky.com/pic/2012/i0412a_1.jpg",
                    //     "thumbnailURLs": null,
                    //     "adId": 0,
                    //     "commentsCount": 40,
                    //     "viewCount": 20437829,
                    //     "dateTime": 1334052574000.0,
                    //     "authorName": "未知",
                    //     "authorHeadImageURL": "https://image.gamersky.com/webimg15/comment/anonymous.jpg",
                    //     "contentURL": null
                    // }
                    var originRelatedContentInfo = response[i];
                    var originRelatedContentInfoThumbnailUrls = [originRelatedContentInfo.thumbnailUrl];
                    if (typeof (originRelatedContentInfo.thumbnailURLs) != "undefined"
                        && originRelatedContentInfo.thumbnailURLs != null
                        && originRelatedContentInfo.thumbnailURLs instanceof Array
                        && originRelatedContentInfo.thumbnailURLs.length > 0)
                    {
                        originRelatedContentInfoThumbnailUrls = originRelatedContentInfo.thumbnailURLs;
                    }
                    var listElement
                        = new GSApp.Modules.ListElement(
                            originRelatedContentInfo.type,
                            originRelatedContentInfo.title,
                            originRelatedContentInfoThumbnailUrls,
                            originRelatedContentInfo.dateTime,
                            originRelatedContentInfo.commentsCount,
                            //
                            originRelatedContentInfo.contentType,
                            originRelatedContentInfo.contentId,
                            originRelatedContentInfo.contentURL);
                    { }
                    relatedContentInfes.push(listElement);
                }
            }
        }
        catch (exception)
        {
            console.log(exception);
            //
            relatedContentInfes = new Array();
        }
        // !!!
        didReceiveRelatedContentInfes(relatedContentInfes);
        // !!!
    });

    GSApp.API.post(
        "http://appapi2.gamersky.com/v2/TwoCorrelation",
        "JSON",
        JSON.stringify(requestParams),
        true,
        appCallback);
}